@@ -49,9 +49,9 @@ def _registe_model(admin, model):
         inline_fields = []
         for inline in getattr(admin, 'inlines', []):
             inline_model = inline.model
-            if issubclass(inline, GenericInlineModelAdmin):
-                ct_field = inline.ct_field
-                ct_fk_field = inline.ct_fk_field
+            if getattr(inline, 'generic_inline', False):
+                ct_field = getattr(inline, 'ct_field', 'content_type')
+                ct_fk_field = getattr(inline, 'ct_fk_field', 'object_id')
                 for field in model._meta.many_to_many:
                     if isinstance(field, GenericRelation) and field.rel.to == inline_model and field.object_id_field_name == ct_fk_field and field.content_type_field_name == ct_field:
                         inline_fields.append(field.name)
