@@ -4,11 +4,11 @@ jQuery(function($){
         if($(this).hasClass('active')){
             // reset
             $('#left-side, ul.breadcrumb').show('fast');
-            $('#content-block').removeClass('col-lg-12 col-sm-12 full-content').addClass('col-sm-11 col-lg-10');
+            $('#content-block').removeClass('col-md-12 col-sm-12 full-content').addClass('col-sm-11 col-md-10');
         } else {
             // full screen
             $('#left-side, ul.breadcrumb').hide('fast', function(){
-                $('#content-block').removeClass('col-sm-11 col-lg-10').addClass('col-lg-12 col-sm-12 full-content');
+                $('#content-block').removeClass('col-sm-11 col-md-10').addClass('col-md-12 col-sm-12 full-content');
             });
         }
     });
