@@ -1,3 +1,4 @@
+import sys
 import copy
 import functools
 import datetime
@@ -190,6 +191,14 @@ class BaseAdminObject(object):
     def template_response(self, template, context):
         return TemplateResponse(self.request, template, context, current_app=self.admin_site.name)
 
+    def message_user(self, message, level='info'):
+        """
+        Send a message to the user. The default implementation
+        posts a message using the django.contrib.messages backend.
+        """
+        if hasattr(messages, level) and callable(getattr(messages, level)):
+            getattr(messages, level)(self.request, message)
+
     def static(self, path):
         return static(path)
 
@@ -283,6 +292,7 @@ class BaseAdminView(BaseAdminObject, View):
 class CommAdminView(BaseAdminView):
 
     base_template = 'xadmin/base_site.html'
+    menu_template = 'xadmin/includes/sitemenu_default.html'
 
     site_title = None
     globe_models_icon = {}
@@ -325,8 +335,23 @@ class CommAdminView(BaseAdminView):
             if app_key in nav_menu:
                 nav_menu[app_key]['menus'].append(model_dict)
             else:
+                # Find app title
+                app_title = unicode(app_label.title())
+                if app_label.lower() in self.apps_label_title:
+                    app_title = self.apps_label_title[app_label.lower()]
+                else:
+                    mods = model.__module__.split('.')
+                    if len(mods) > 1:
+                        mod = '.'.join(mods[0:-1])
+                        if mod in sys.modules:
+                            mod = sys.modules[mod]
+                            if 'verbose_name' in dir(mod):
+                                app_title = getattr(mod, 'verbose_name')
+                            elif 'app_title' in dir(mod):
+                                app_title = getattr(mod, 'app_title')
+
                 nav_menu[app_key] = {
-                    'title': self.apps_label_title.get(app_label.lower(), unicode(app_label.title())),
+                    'title': app_title,
                     'menus': [model_dict],
                 }
 
@@ -399,9 +424,12 @@ class CommAdminView(BaseAdminView):
         for menu in nav_menu:
             check_selected(menu, self.request.path)
 
-        context['nav_menu'] = nav_menu
-        context['site_title'] = self.site_title or _(u'Django Xadmin')
-        context['breadcrumbs'] = self.get_breadcrumb()
+        context.update({
+            'menu_template': self.menu_template,
+            'nav_menu': nav_menu,
+            'site_title': self.site_title or _(u'Django Xadmin'),
+            'breadcrumbs': self.get_breadcrumb()
+        })
 
         return context
 
@@ -413,15 +441,6 @@ class CommAdminView(BaseAdminView):
                            'model_icon', self.default_model_icon)
         return icon
 
-    @filter_hook
-    def message_user(self, message, level='info'):
-        """
-        Send a message to the user. The default implementation
-        posts a message using the django.contrib.messages backend.
-        """
-        if hasattr(messages, level) and callable(getattr(messages, level)):
-            getattr(messages, level)(self.request, message)
-
     @filter_hook
     def get_breadcrumb(self):
         return [{
