@@ -36,6 +36,7 @@ FORMFIELD_FOR_DBFIELD_DEFAULTS = {
     models.FileField: {'widget': widgets.AdminFileWidget},
     models.ForeignKey: {'widget': widgets.AdminSelectWidget},
     models.OneToOneField: {'widget': widgets.AdminSelectWidget},
+    models.ManyToManyField: {'widget': widgets.AdminSelectMultiple},
 }
 
 
@@ -92,7 +93,7 @@ class ModelFormAdminView(ModelAdminView):
     def get_field_style(self, db_field, style, **kwargs):
         if style in ('radio', 'radio-inline') and (db_field.choices or isinstance(db_field, models.ForeignKey)):
             attrs = {'widget': widgets.AdminRadioSelect(
-                attrs={'class': 'radio-inline' if style == 'radio-inline' else ""})}
+                attrs={'inline': style == 'radio-inline'})}
             if db_field.choices:
                 attrs['choices'] = db_field.get_choices(
                     include_blank=db_field.blank,
@@ -101,7 +102,7 @@ class ModelFormAdminView(ModelAdminView):
             return attrs
 
         if style in ('checkbox', 'checkbox-inline') and isinstance(db_field, models.ManyToManyField):
-            return {'widget': widgets.AdminCheckboxSelect(attrs={'class': 'checkbox-inline' if style == 'checkbox-inline' else ""}),
+            return {'widget': widgets.AdminCheckboxSelect(attrs={'inline': style == 'checkbox-inline'}),
                     'help_text': None}
 
     @filter_hook
@@ -393,12 +394,12 @@ class CreateAdminView(ModelFormAdminView):
             'The %(name)s "%(obj)s" was added successfully.') % {'name': force_unicode(self.opts.verbose_name),
                                                                  'obj': "<a class='alert-link' href='%s'>%s</a>" % (self.model_admin_url('change', self.new_obj._get_pk_val()), force_unicode(self.new_obj))}
 
-        if "_continue" in request.POST:
+        if "_continue" in request.REQUEST:
             self.message_user(
                 msg + ' ' + _("You may edit it again below."), 'success')
             return self.model_admin_url('change', self.new_obj._get_pk_val())
 
-        if "_addanother" in request.POST:
+        if "_addanother" in request.REQUEST:
             self.message_user(msg + ' ' + (_("You may add another %s below.") % force_unicode(self.opts.verbose_name)), 'success')
             return request.path
         else:
@@ -407,7 +408,9 @@ class CreateAdminView(ModelFormAdminView):
             # Figure out where to redirect. If the user has change permission,
             # redirect to the change-list page for this object. Otherwise,
             # redirect to the admin index.
-            if self.has_view_permission():
+            if "_redirect" in request.REQUEST:
+                return request.REQUEST["_redirect"]
+            elif self.has_view_permission():
                 return self.model_admin_url('changelist')
             else:
                 return self.get_admin_url('index')
@@ -468,7 +471,7 @@ class UpdateAdminView(ModelFormAdminView):
             context, current_app=self.admin_site.name)
 
     def post(self, request, *args, **kwargs):
-        if "_saveasnew" in self.request.POST:
+        if "_saveasnew" in self.request.REQUEST:
             return self.get_model_view(CreateAdminView, self.model).post(request)
         return super(UpdateAdminView, self).post(request, *args, **kwargs)
 
@@ -486,11 +489,11 @@ class UpdateAdminView(ModelFormAdminView):
 
         msg = _('The %(name)s "%(obj)s" was changed successfully.') % {'name':
                                                                        force_unicode(verbose_name), 'obj': force_unicode(obj)}
-        if "_continue" in request.POST:
+        if "_continue" in request.REQUEST:
             self.message_user(
                 msg + ' ' + _("You may edit it again below."), 'success')
             return request.path
-        elif "_addanother" in request.POST:
+        elif "_addanother" in request.REQUEST:
             self.message_user(msg + ' ' + (_("You may add another %s below.")
                               % force_unicode(verbose_name)), 'success')
             return self.model_admin_url('add')
@@ -499,7 +502,9 @@ class UpdateAdminView(ModelFormAdminView):
             # Figure out where to redirect. If the user has change permission,
             # redirect to the change-list page for this object. Otherwise,
             # redirect to the admin index.
-            if self.has_view_permission():
+            if "_redirect" in request.REQUEST:
+                return request.REQUEST["_redirect"]
+            elif self.has_view_permission():
                 change_list_url = self.model_admin_url('changelist')
                 if 'LIST_QUERY' in self.request.session \
                 and self.request.session['LIST_QUERY'][0] == self.model_info:
